@@ -37,7 +37,7 @@ LDAPObject_delete(LDAPObject *self, PyObject *args)
 	rc = ldap_delete_ext(self->ldap, dn, sctrls, cctrls, &msgid);
 	LDAP_END_ALLOW_THREADS
 	if (rc != LDAP_SUCCESS) {
-		PyErr_SetString(LDAPError, ldap_err2string(rc));
+		PyErr_Format(LDAPError, "%s (%d)", ldap_err2string(rc), rc);
 		return NULL;
 	}
 	return PyLong_FromLong(msgid);
